<h1>Pytoolkit (Open-Python-CLI-Tools)</h1>

![GitHub license](https://img.shields.io/github/license/Leomb-coder/Pytoolkit)
![Top language](https://img.shields.io/github/languages/top/Leomb-coder/Pytoolkit.svg)
![Commits](https://img.shields.io/github/commit-activity/t/Leomb-coder/Pytoolkit/main.svg)
![Open issues](https://img.shields.io/github/issues/Leomb-coder/Pytoolkit.svg)
![Closed issues](https://img.shields.io/github/issues-closed/Leomb-coder/Pytoolkit.svg)
![Contributors](https://img.shields.io/github/contributors/Leomb-coder/Pytoolkit.svg)

A collection of open-source Python CLI utilities designed to simplify everyday tasks.
Built with Typer, Pathlib, and Rich, Pytoolkit provides a lightweight and extensible way to manage small command-line tools in one place.<br>
<i>(Under development. Any help is appreciated.)</i>

<h3>The current tools include:</h3>
<ul>
  <li>Rename prefix_sulfix(rename_ps) - Rename all files in a directory using prefixes and suffixes:<br> <code>{prefix}{current_file_name}{suffix} - <i>new_</i>file<i>_photo</i>.png</code>. </li><br>
  <li>Rename sequentially(rename_sqt) - Rename all files in a directory sequentially:<br> <code>{new_file_name}_(<number>){extension} - poto_(1).png</code></li><br>
  <li>Show path(show_path) - Shows path of current directory.</li><br>
  <li>Show parent(show_parent) - Shows parent of input directory.</li><br>
</ul>
